"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addCopyLocalizedResources = exports.getEntryPoints = exports.getLoggingLevel = exports.setDefaultServeSettings = exports.getJSONFile = void 0;
const path = __importStar(require("path"));
const fs = __importStar(require("fs"));
function getJSONFile(relPath) {
    return require(path.join(process.cwd(), relPath));
}
exports.getJSONFile = getJSONFile;
function setDefaultServeSettings(settings) {
    const defaultServeSettings = {
        open: true,
        fullScreenErrors: true,
        loggingLevel: 'normal'
    };
    settings.serve = settings.serve || {};
    settings.serve = Object.assign(defaultServeSettings, settings.serve);
    if (settings.cli.isLibraryComponent) {
        settings.serve.open = false;
    }
}
exports.setDefaultServeSettings = setDefaultServeSettings;
function getLoggingLevel(level) {
    if (level === 'minimal') {
        return {
            all: false,
            colors: true,
            errors: true
        };
    }
    if (level === 'normal') {
        return {
            all: false,
            colors: true,
            errors: true,
            timings: true,
            entrypoints: true
        };
    }
    if (level === 'detailed') {
        return {
            all: false,
            colors: true,
            errors: true,
            timings: true,
            assets: true,
            warnings: true
        };
    }
    throw new Error('Unsupported log level: ' + level);
}
exports.getLoggingLevel = getLoggingLevel;
function getEntryPoints(entry) {
    const newEntry = {};
    for (const key in entry) {
        let entryPath = entry[key];
        if (entryPath.indexOf('bundle-entries') === -1) {
            entryPath = createTsEntryPath(entryPath);
        }
        else {
            let bundleContent = fs.readFileSync(entryPath).toString();
            bundleContent = createTsEntriesForBundledPackage(bundleContent);
            fs.writeFileSync(entryPath, bundleContent);
        }
        newEntry[key] = entryPath;
    }
    return newEntry;
}
exports.getEntryPoints = getEntryPoints;
function createTsEntriesForBundledPackage(content) {
    const search = /require\('(?<jsPath>.*)'\)/gi;
    let newContent = content.slice();
    let match = search.exec(content);
    do {
        const jsPath = match.groups.jsPath;
        const tsPath = createTsEntryPath(jsPath);
        newContent = newContent.replace(jsPath, tsPath);
    } while ((match = search.exec(content)) !== null);
    return newContent;
}
function createTsEntryPath(jsPath) {
    const libSearchRegexp1 = /\/lib\//gi;
    const libSearchRegexp2 = /\\lib\\/gi;
    const srcPathToReplace1 = '/src/';
    const srcPathToReplace2 = '\\src\\';
    const tsPath = jsPath
        .replace(libSearchRegexp1, srcPathToReplace1)
        .replace(libSearchRegexp2, srcPathToReplace2)
        .slice(0, -3) + '.ts';
    return getEntryPath(tsPath);
}
function getEntryPath(tsPath) {
    if (fs.existsSync(tsPath)) {
        return tsPath;
    }
    tsPath = tsPath + 'x';
    if (fs.existsSync(tsPath)) {
        return tsPath;
    }
    throw new Error('Unable to resolve entry path. Path received: ' + tsPath);
}
function addCopyLocalizedResources(localizedResources) {
    const patterns = [];
    for (const resourceKey in localizedResources) {
        const resourcePath = localizedResources[resourceKey];
        const from = resourcePath.replace(/^lib/gi, 'src').replace('{locale}', '*');
        patterns.push({
            flatten: true,
            from,
            to: (data) => {
                const fileName = path.basename(data.absoluteFilename);
                return resourceKey + '_' + fileName;
            }
        });
    }
    return patterns;
}
exports.addCopyLocalizedResources = addCopyLocalizedResources;
//# sourceMappingURL=helpers.js.map